==> haskell-ini-0.3.6-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ini
version: 0.3.6
id: ini-0.3.6-FtFVe6IzKqnBIxwHjQfUp1
key: ini-0.3.6-FtFVe6IzKqnBIxwHjQfUp1
license: BSD-3-Clause
copyright: 2013 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
homepage: http://github.com/chrisdone/ini
synopsis: Quick and easy configuration files in the INI format.
description:
    Quick and easy configuration files in the INI format.
category: Data, Configuration
abi: b53c2670a733a2fddedbd5d188d1dda9
exposed: True
exposed-modules:
    Data.Ini
import-dirs: /usr/lib/ghc-8.4.3/site-local/ini-0.3.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/ini-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ini-0.3.6
hs-libraries: HSini-0.3.6-FtFVe6IzKqnBIxwHjQfUp1
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-7kmhoL5l3stA3NDsk1DtWk
    text-1.2.3.0 unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             attoparsec-0.13.2.2-7kmhoL5l3stA3NDsk1DtWk=825d47e693044b92530553d85386444f
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html: /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ini-0.3.6-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ini
version: 0.3.6
id: ini-0.3.6-DbiBswdivtzAvXwZsxzD9w
key: ini-0.3.6-DbiBswdivtzAvXwZsxzD9w
license: BSD-3-Clause
copyright: 2013 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
homepage: http://github.com/chrisdone/ini
synopsis: Quick and easy configuration files in the INI format.
description:
    Quick and easy configuration files in the INI format.
category: Data, Configuration
abi: 9b754e8a3252fff05b8a669cc1040222
exposed: True
exposed-modules:
    Data.Ini
import-dirs: /usr/lib/ghc-8.4.3/site-local/ini-0.3.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/ini-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ini-0.3.6
hs-libraries: HSini-0.3.6-DbiBswdivtzAvXwZsxzD9w
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK
    text-1.2.3.0 unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK=fff7ae21f45c1b0af12007963cebbf81
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html: /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
